<?php
/**
 * This file contains all, program settings for amazOOP.
 *
 * An average user wouldn't want to touch this file. But I encourage
 * you to look at it if you want to understand exactly how amazOOP
 * works and/or if you want to contribute to its development.
 *
 * @author Mauricio Diaz <madd0@users.sourceforge.net>
 * @copyright 2004 (c) Mauricio Diaz Orlich
 * @license http://www.gnu.org/licenses/gpl.html GNU Public License
 * @version 0.3RC2
 *
 * @package amazOOP
 * @subpackage Configuration
 */

/**
 * For security, only {@link aq.php} should be included in your pages
 */
defined( '_AMAZOOP' ) or die( 'Direct Access to this location is not allowed.' );

/**
 * The version of amazOOP you are using
 * @global string _AMAZOOP_VERSION
 */
define('_AMAZOOP_VERSION', '0.3RC2');

/**
 * Addresses to different Amazon Web Services servers.
 * French and Canadian Web Services aren't running yet.
 * @global array $_AMAZOOP_SITES
 * @access private
 */
$_AMAZOOP_SITES = array( "us" => "http://xml.amazon.com/onca/xml3?f=xml",
                         "uk" => "http://xml-eu.amazon.com/onca/xml3?f=xml&locale=uk",
                         "de" => "http://xml-eu.amazon.com/onca/xml3?f=xml&locale=de",
                         "jp" => "http://xml.amazon.co.jp/onca/xml3?f=xml&locale=jp"
                        );

/**
 * Currently supported search types.
 * These are simply "nicknames" for the search types officially supported by AWS,
 * in order to use shorter arguments.
 * You MUST use amazOOPs search types instead of AWS's when you query
 * AWS through amazOOP.
 *
 * @global array $_AMAZOOP_SEARCH_TYPES
 *
 * @todo Exchange Searches
 * @todo Listmania! Searches
 * @todo Marketplace Searches
 * @todo Power Searches
 * @todo Seller Profile Searches
 * @todo Text Stream Searches
 * @todo Third Party Searches
 * @todo Wishlist Searches
 *
 * @access private
 */
$_AMAZOOP_SEARCH_TYPES = array( "Actor"        => "ActorSearch",
                                "Artist"       => "ArtistSearch",
                                "ASIN"         => "AsinSearch",
                                "ISBN"         => "AsinSearch",
                                "Author"       => "AuthorSearch",
                                "Blended"      => "BlendedSearch",
                                "BrowseNode"   => "BrowseNodeSearch",
                                "Director"     => "DirectorSearch",
                                "Keywords"     => "KeywordSearch",
                                "ListMania"    => "ListManiaSearch",
                                "Manufacturer" => "ManufacturerSearch",
                                "Power"        => "PowerSearch",
                                "Similarity"   => "SimilaritySearch",
                                "UPC"          => "UpcSearch",
                                "Wishlist"     => "WishlistSearch"
                               );



/**
 * Sorting options for different product types.
 * This isn't very well documented in the SDK so I can't document it,
 * or implement it correctly...
 *
 * @global array $_AMAZOOP_SORTING
 *
 * @access private
 */
$_AMAZOOP_SORTING = array( "books" => array(           "FeaturedItems"   => "+pmrank",
                                                       "Bestselling"     => "+salesrank",
                                                       "Reviews"         => "+reviewrank",
                                                       "PriceInc"        => "+pricerank",
                                                       "PriceDec"        => "+inverse-pricerank",
                                                       "Date"            => "+daterank",
                                                       "AlphaInc"        => "+titlerank",
                                                       "AlphaDec"        => "-titlerank"),

                           "software" => array(        "FeaturedItems"   => "+pmrank",
                                                       "Bestselling"     => "+salesrank",
                                                       "AlphaInc"        => "+titlerank",
                                                       "PriceDec"        => "+price",
                                                       "PriceInc"        => "-price"),

                           "garden" => array(          "FeaturedItems"   => "+psrank",
                                                       "Bestselling"     => "+salesrank",
                                                       "AlphaInc"        => "+titlerank",
                                                       "AlphaDec"        => "-titlerank",
                                                       "ManufacturerInc" => "+manufactrank",
                                                       "ManufacturerDec" => "-manufactrank",
                                                       "PriceInc"        => "+price",
                                                       "PriceDec"        => "-price"),

                           "tools" => array(           "FeaturedItems"   => "+psrank",
                                                       "Bestselling"     => "+salesrank",
                                                       "AlphaInc"        => "+titlerank",
                                                       "AlphaDec"        => "-titlerank",
                                                       "ManufacturerInc" => "+manufactrank",
                                                       "ManufacturerDec" => "-manufactrank",
                                                       "PriceInc"        => "+price",
                                                       "PriceDec"        => "-price"),

                           "photo" => array(           "FeaturedItems"   => "+pmrank",
                                                       "Bestselling"     => "+salesrank",
                                                       "AlphaInc"        => "+titlerank",
                                                       "AlphaDec"        => "-titlerank"),

                           "pc-hardware" => array(     "FeaturedItems"   => "+psrank",
                                                       "Bestselling"     => "+salesrank",
                                                       "AlphaInc"        => "+titlerank",
                                                       "AlphaDec"        => "-titlerank"),

                           "videogames" => array(      "FeaturedItems"   => "+pmrank",
                                                       "Bestselling"     => "+salesrank",
                                                       "AlphaInc"        => "+titlerank",
                                                       "PriceInc"        => "+price",
                                                       "PriceDec"        => "-price"),

                           "music" => array(           "FeaturedItems"   => "+psrank",
                                                       "Bestselling"     => "+salesrank",
                                                       "Artist"          => "+artistrank",
                                                       "Date"            => "+orig-rel-date",
                                                       "AlphaInc"        => "+titlerank"),

                           "office-products" => array( "FeaturedItems"   => "+pmrank",
                                                       "Bestselling"     => "+salesrank",
                                                       "AlphaInc"        => "+titlerank",
                                                       "AlphaDec"        => "-titlerank",
                                                       "PriceInc"        => "+price",
                                                       "PriceDec"        => "-price",
                                                       "Review"          => "+reviewrank"),

                           "vhs" => array(             "FeaturedItems"   => "+psrank",
                                                       "Bestselling"     => "+salesrank",
                                                       "AlphaInc"        => "+titlerank"),

                           "electronics" => array(     "FeaturedItems"   => "+pmrank",
                                                       "Bestselling"     => "+salesrank",
                                                       "AlphaInc"        => "+titlerank",
                                                       "Review"          => "+reviewrank"),

                           "kitchen" => array(         "FeaturedItems"   => "+pmrank",
                                                       "Bestselling"     => "+salesrank",
                                                       "AlphaInc"        => "+titlerank",
                                                       "AlphaDec"        => "-titlerank",
                                                       "ManufacturerInc" => "+manufactrank",
                                                       "ManufacturerDec" => "-manufactrank",
                                                       "PriceInc"        => "+price",
                                                       "PriceDec"        => "-price"),

                           "toys" => array(            "FeaturedItems"   => "+pmrank",
                                                       "Bestselling"     => "+salesrank",
                                                       "PriceInc"        => "+pricerank",
                                                       "PriceDec"        => "+inverse-pricerank",
                                                       "AlphaInc"        => "+titlerank"),

                           "all" => array(             "Bestselling"     => "+salesrank",
                                                       "AlphaInc"        => "+titlerank")
                         );
/**
 * An array containing the developer's associate IDs for each of
 * Amazon's sites.
 * These IDs are only used if you request an ID for a site for which
 * you have not setup an ID of your own.
 *
 * @global array $_AMAZOOP_MADD0S_IDS
 *
 * @access private
 */
$_AMAZOOP_MADD0S_IDS = array( 'us' => 'madd0inc',
                              'uk' => 'madd0mall',
                              'fr' => 'themadd0mall-21',
                              'de' => 'dermadd0mall',
                              'jp' => 'themadd0mall-22',
                              'ca' => 'themadd0mall-20'
                             );

/**
 * Contains an array with the IDs of thrid party sellers
 * @access private
 */
require_once("stores.inc.php");
/**
 * Contains an array with the amazOOP categories
 * @access private
 */
require_once("categories.inc.php");
/**
 * Contains the user's configuration settings
 * @access private
 */
require_once("userdata.inc.php");
/**
 * Contains an array valid AWS modes
 * @access private
 */
require_once("modes.inc.php");
/**
 * Contains an array with settings for RSS feeds
 * @access private
 */
require_once("rss.inc.php");
?>